<?php

use Dotenv\Dotenv;
use Dotenv\Repository\Adapter\EnvConstAdapter;
use Dotenv\Repository\Adapter\ServerConstAdapter;
use Dotenv\Repository\RepositoryBuilder;

define('WP_ROOT_DIR', dirname(__DIR__));

/**
 * Use Dotenv to set required environment variables and load .env file in root
 */

$adapters = [
    new EnvConstAdapter(),
    new ServerConstAdapter(),
];

$repository = RepositoryBuilder::create()
    ->withReaders($adapters)
    ->withWriters($adapters)
    ->immutable()
    ->make();

Dotenv::create($repository, WP_ROOT_DIR, '.env')->load();


/**
 * Set up our global environment constant and load its config first
 * Default: production
 */
define('WP_ENVIRONMENT_TYPE', $_ENV['WP_ENVIRONMENT_TYPE']);
define('DB_NAME', $_ENV['DB_NAME']);
define('DB_USER', $_ENV['DB_USER']);
define('DB_PASSWORD', $_ENV['DB_PASSWORD']);
define('DB_HOST', $_ENV['DB_HOST']);

define('WP_MEMORY_LIMIT', ini_get('memory_limit'));

define('WP_HOME', $_ENV['WP_HOME']);
define('WP_SITEURL', WP_HOME);


$envConfig = __DIR__ . '/environments/' . WP_ENV . '.php';

if (file_exists($envConfig)) {
    require_once($envConfig);
} else {
    /* Production */
    define('SAVEQUERIES', false);
    define('WP_DEBUG', false);
    ini_set('display_errors', 0);
    define('WP_DEBUG_DISPLAY', false);
    define('WP_DEBUG_LOG', false);
    define('SCRIPT_DEBUG', false);
}

/**
 * Custom Content Directory
 */
define('WP_CONTENT_DIR', WP_ROOT_DIR . '/content');
define('WP_CONTENT_URL', WP_HOME . '/content');

/**
 * DB settings
 */
define('DB_CHARSET', 'utf8');
define('DB_COLLATE', '');
$table_prefix = $_ENV['DB_PREFIX'];

/**
 * Authentication Unique Keys and Salts
 */
define('AUTH_KEY', $_ENV['AUTH_KEY']);
define('SECURE_AUTH_KEY', $_ENV['SECURE_AUTH_KEY']);
define('LOGGED_IN_KEY', $_ENV['LOGGED_IN_KEY']);
define('NONCE_KEY', $_ENV['NONCE_KEY']);
define('AUTH_SALT', $_ENV['AUTH_SALT']);
define('SECURE_AUTH_SALT', $_ENV['SECURE_AUTH_SALT']);
define('LOGGED_IN_SALT', $_ENV['LOGGED_IN_SALT']);
define('NONCE_SALT', $_ENV['NONCE_SALT']);

/**
 * Network
 */
define('WP_ALLOW_MULTISITE', false);

if (WP_ALLOW_MULTISITE == true) {
    $wpHome = explode('/', WP_HOME);
    $domainCurrentSite = $wpHome[2];

    define('MULTISITE', false);
    define('SUBDOMAIN_INSTALL', false);
    define('DOMAIN_CURRENT_SITE', $domainCurrentSite);
    define('PATH_CURRENT_SITE', '/');
    define('SITE_ID_CURRENT_SITE', 1);
    define('BLOG_ID_CURRENT_SITE', 1);
}

/**
 * Custom Settings
 */
define('DISALLOW_FILE_EDIT', true);

/**
 * Bootstrap WordPress
 */
if (!defined('ABSPATH')) {
    define('ABSPATH', WP_ROOT_DIR . '/wp/');
}
